==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS","Tous les Sujets");
define("_NOCOMMENTS","Pas de commentaires");

define("_UCOMMENT","Commentaire");
define("_REVIEWS","Comptes rendus");
define("_SEARCHUSERS","Rechercher dans la base de donn&eacute;es des utilisateurs");
define("_SEARCHSECTIONS","Rechercher dans les rubriques sp&eacute;ciales");
define("_SEARCHREVIEWS","Rechercher dans les comptes rendus");
define("_SEARCHIN","Rechercher dans");
define("_ARTICLES","Articles");
define("_ALLAUTHORS","Tous les Auteurs");
define("_ALL","Tous");
define("_WEEK","semaine");
define("_WEEKS","semaines");
define("_MONTH","mois");
define("_MONTHS","mois");
define("_SEARCHON","Chercher dans:");
define("_SSTORIES","Articles");
define("_SSECTIONS","Rubriques");
define("_SUSERS","Utilisateurs");
define("_NOMATCHES","Aucune correspondance trouv&eacute;e &agrave; votre requ&ecirc;te");
define("_PREVMATCHES","R&eacute;ponses Pr&eacute;c&eacute;dentes");
define("_NEXTMATCHES","R&eacute;ponses Suivantes");
define("_INSECTION","dans la rubrique");
define("_NONAME","Pas de nom saisi");
define("_SCOMMENTS","Commentaires");
define("_SEARCHRESULTS","R&eacute;sultats de la recherche");
define("_CONTRIBUTEDBY","Contribution de");
define("_UCOMMENTS","Commentaires");
define("_MATCHTITLE","Concordance dans le titre");
define("_MATCHTEXT","Concordance dans le texte de l'article");
define("_MATCHBOTH","Concordance dans le titre et dans le texte de l'article");
define("_SREPLY","R&eacute;pondre");
define("_SREPLIES","R&eacute;ponses");
define("_ATTACHART","Attach&eacute; &agrave; l'article");
define("_PAGES","Pages");
define("_REVIEWSCORE","Score pour ce compte rendu");
define("_PAGE","Page");



?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS","Tous les Sujets");
define("_NOCOMMENTS","Pas de commentaires");

define("_UCOMMENT","Commentaire");
define("_REVIEWS","Comptes rendus");
define("_SEARCHUSERS","Rechercher dans la base de donn&eacute;es des utilisateurs");
define("_SEARCHSECTIONS","Rechercher dans les rubriques sp&eacute;ciales");
define("_SEARCHREVIEWS","Rechercher dans les comptes rendus");
define("_SEARCHIN","Rechercher dans");
define("_ARTICLES","Articles");
define("_ALLAUTHORS","Tous les Auteurs");
define("_ALL","Tous");
define("_WEEK","semaine");
define("_WEEKS","semaines");
define("_MONTH","mois");
define("_MONTHS","mois");
define("_SEARCHON","Chercher dans:");
define("_SSTORIES","Articles");
define("_SSECTIONS","Rubriques");
define("_SUSERS","Utilisateurs");
define("_NOMATCHES","Aucune correspondance trouv&eacute;e &agrave; votre requ&ecirc;te");
define("_PREVMATCHES","R&eacute;ponses Pr&eacute;c&eacute;dentes");
define("_NEXTMATCHES","R&eacute;ponses Suivantes");
define("_INSECTION","dans la rubrique");
define("_NONAME","Pas de nom saisi");
define("_SCOMMENTS","Commentaires");
define("_SEARCHRESULTS","R&eacute;sultats de la recherche");
define("_CONTRIBUTEDBY","Contribution de");
define("_UCOMMENTS","Commentaires");
define("_MATCHTITLE","Concordance dans le titre");
define("_MATCHTEXT","Concordance dans le texte de l'article");
define("_MATCHBOTH","Concordance dans le titre et dans le texte de l'article");
define("_SREPLY","R&eacute;pondre");
define("_SREPLIES","R&eacute;ponses");
define("_ATTACHART","Attach&eacute; &agrave; l'article");
define("_PAGES","Pages");
define("_REVIEWSCORE","Score pour ce compte rendu");
define("_PAGE","Page");



?>
